Module border

Module border 

QR Border Plugin

A plugin to add customizable borders and decorations to QR codes. Supports outer, main, and inner borders, as well as text or image decorations along each side.

Structs

BorderDecoration
Decoration configuration for text or image decorations.
BorderOptions
Style options for border elements.
BorderPlugin
Border plugin for adding borders and decorations to QR codes.
QRBorderOptions
Extension options for the QR Border Plugin.

Enums

DecorationType
Type of decoration that can be applied to the QR code borders.
Position
Position for specifying where decorations should be placed.