QRBorderOptions

Struct QRBorderOptions 

pub struct QRBorderOptions {
    pub border: BorderOptions,
    pub round: f64,
    pub border_inner: Option<BorderOptions>,
    pub border_outer: Option<BorderOptions>,
    pub decorations: HashMap<Position, BorderDecoration>,
}
Extension options for the QR Border Plugin.

Fields

border: BorderOptions

Main border options

round: f64

Corner roundness (0.0 = square, 1.0 = fully round)

border_inner: Option<BorderOptions>

Optional inner border

border_outer: Option<BorderOptions>

Optional outer border

decorations: HashMap<Position, BorderDecoration>

Decorations mapped by position

Implementations

Source

impl QRBorderOptions

pub fn new(thickness: f64, color: impl Into<String>) -> Self

Create new border options with specified thickness and color.

pub fn with_round(self, round: f64) -> Self

Set corner roundness.

pub fn with_inner_border(self, options: BorderOptions) -> Self

Set inner border.

pub fn with_outer_border(self, options: BorderOptions) -> Self

Set outer border.

pub fn with_decoration( self, position: Position, decoration: BorderDecoration, ) -> Self

Add a decoration at the specified position.

pub fn with_text(self, position: Position, text: impl Into<String>) -> Self

Add text decoration at the specified position.

pub fn with_styled_text( self, position: Position, text: impl Into<String>, style: impl Into<String>, ) -> Self

Add text decoration with style at the specified position.