QR Border Plugin
A plugin to add customizable borders and decorations to QR codes. Supports outer, main, and inner borders, as well as text or image decorations along each side.
Structs
- Border
Decoration - Decoration configuration for text or image decorations.
- Border
Options - Style options for border elements.
- Border
Plugin - Border plugin for adding borders and decorations to QR codes.
- QRBorder
Options - Extension options for the QR Border Plugin.
Enums
- Decoration
Type - Type of decoration that can be applied to the QR code borders.
- Position
- Position for specifying where decorations should be placed.